@@ -1,7 +1,7 @@
 '''
-[![NPM version](https://badge.fury.io/js/cdk-iotfleetwise.svg)](https://badge.fury.io/js/cdk-iotfleetwise)
-[![PyPI version](https://badge.fury.io/py/cdk-iotfleetwise.svg)](https://badge.fury.io/py/cdk-iotfleetwise)
-[![release](https://github.com/aws-samples/cdk-iotfleetwise/actions/workflows/release.yml/badge.svg)](https://github.com/aws-samples/cdk-iotfleetwise/actions/workflows/release.yml)
+[![NPM version](https://badge.fury.io/js/cdk-aws-iotfleetwise.svg)](https://badge.fury.io/js/cdk-aws-iotfleetwise)
+[![PyPI version](https://badge.fury.io/py/cdk-aws-iotfleetwise.svg)](https://badge.fury.io/py/cdk-aws-iotfleetwise)
+[![release](https://github.com/aws-samples/cdk-aws-iotfleetwise/actions/workflows/release.yml/badge.svg)](https://github.com/aws-samples/cdk-aws-iotfleetwise/actions/workflows/release.yml)
 
 # cdk-aws-iotfleetwise
 
@@ -115,7 +115,6 @@ Warning: this construct should be considered at alpha stage and is not feature c
 * Reduce Lambda log retention to 1d
 * Apply the least priviledge principle to roles
 * Implement updates for all the custom resources
-* Fleet
 * Conditional campaigns
 
 ## Security
@@ -223,6 +222,47 @@ class CollectionScheme(
         jsii.set(self, "scheme", value)
 
 
+class Fleet(
+    constructs.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="cdk-aws-iotfleetwise.Fleet",
+):
+    '''The fleet of vehicles.'''
+
+    def __init__(
+        self,
+        scope: constructs.Construct,
+        id: builtins.str,
+        props: "IFleet",
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param props: -
+        '''
+        jsii.create(self.__class__, self, [scope, id, props])
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="arn")
+    def arn(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "arn"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="fleetId")
+    def fleet_id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "fleetId"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="signalCatalog")
+    def signal_catalog(self) -> "SignalCatalog":
+        return typing.cast("SignalCatalog", jsii.get(self, "signalCatalog"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vehicles")
+    def vehicles(self) -> typing.List["Vehicle"]:
+        return typing.cast(typing.List["Vehicle"], jsii.get(self, "vehicles"))
+
+
 @jsii.interface(jsii_type="cdk-aws-iotfleetwise.ICampaign")
 class ICampaign(typing_extensions.Protocol):
     @builtins.property # type: ignore[misc]
@@ -305,6 +345,92 @@ class _ICampaignProxy:
 typing.cast(typing.Any, ICampaign).__jsii_proxy_class__ = lambda : _ICampaignProxy
 
 
+@jsii.interface(jsii_type="cdk-aws-iotfleetwise.IFleet")
+class IFleet(typing_extensions.Protocol):
+    '''Interface.'''
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="fleetId")
+    def fleet_id(self) -> builtins.str:
+        ...
+
+    @fleet_id.setter
+    def fleet_id(self, value: builtins.str) -> None:
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="signalCatalog")
+    def signal_catalog(self) -> "SignalCatalog":
+        ...
+
+    @signal_catalog.setter
+    def signal_catalog(self, value: "SignalCatalog") -> None:
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[builtins.str]:
+        ...
+
+    @description.setter
+    def description(self, value: typing.Optional[builtins.str]) -> None:
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vehicles")
+    def vehicles(self) -> typing.Optional[typing.List["Vehicle"]]:
+        ...
+
+    @vehicles.setter
+    def vehicles(self, value: typing.Optional[typing.List["Vehicle"]]) -> None:
+        ...
+
+
+class _IFleetProxy:
+    '''Interface.'''
+
+    __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.IFleet"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="fleetId")
+    def fleet_id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "fleetId"))
+
+    @fleet_id.setter
+    def fleet_id(self, value: builtins.str) -> None:
+        jsii.set(self, "fleetId", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="signalCatalog")
+    def signal_catalog(self) -> "SignalCatalog":
+        return typing.cast("SignalCatalog", jsii.get(self, "signalCatalog"))
+
+    @signal_catalog.setter
+    def signal_catalog(self, value: "SignalCatalog") -> None:
+        jsii.set(self, "signalCatalog", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
+
+    @description.setter
+    def description(self, value: typing.Optional[builtins.str]) -> None:
+        jsii.set(self, "description", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vehicles")
+    def vehicles(self) -> typing.Optional[typing.List["Vehicle"]]:
+        return typing.cast(typing.Optional[typing.List["Vehicle"]], jsii.get(self, "vehicles"))
+
+    @vehicles.setter
+    def vehicles(self, value: typing.Optional[typing.List["Vehicle"]]) -> None:
+        jsii.set(self, "vehicles", value)
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IFleet).__jsii_proxy_class__ = lambda : _IFleetProxy
+
+
 @jsii.interface(jsii_type="cdk-aws-iotfleetwise.IServiceCatalogProps")
 class IServiceCatalogProps(typing_extensions.Protocol):
     @builtins.property # type: ignore[misc]
@@ -520,15 +646,6 @@ class IVehicleModel(typing_extensions.Protocol):
     def signal_catalog(self, value: "SignalCatalog") -> None:
         ...
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signals")
-    def signals(self) -> typing.List["VehicleSignal"]:
-        ...
-
-    @signals.setter
-    def signals(self, value: typing.List["VehicleSignal"]) -> None:
-        ...
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
@@ -538,6 +655,29 @@ class IVehicleModel(typing_extensions.Protocol):
     def description(self, value: typing.Optional[builtins.str]) -> None:
         ...
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="networkFileDefinitions")
+    def network_file_definitions(
+        self,
+    ) -> typing.Optional[typing.List["NetworkFileDefinition"]]:
+        ...
+
+    @network_file_definitions.setter
+    def network_file_definitions(
+        self,
+        value: typing.Optional[typing.List["NetworkFileDefinition"]],
+    ) -> None:
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="signals")
+    def signals(self) -> typing.Optional[typing.List["VehicleSignal"]]:
+        ...
+
+    @signals.setter
+    def signals(self, value: typing.Optional[typing.List["VehicleSignal"]]) -> None:
+        ...
+
 
 class _IVehicleModelProxy:
     __jsii_type__: typing.ClassVar[str] = "cdk-aws-iotfleetwise.IVehicleModel"
@@ -569,15 +709,6 @@ class _IVehicleModelProxy:
     def signal_catalog(self, value: "SignalCatalog") -> None:
         jsii.set(self, "signalCatalog", value)
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="signals")
-    def signals(self) -> typing.List["VehicleSignal"]:
-        return typing.cast(typing.List["VehicleSignal"], jsii.get(self, "signals"))
-
-    @signals.setter
-    def signals(self, value: typing.List["VehicleSignal"]) -> None:
-        jsii.set(self, "signals", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
@@ -587,10 +718,54 @@ class _IVehicleModelProxy:
     def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="networkFileDefinitions")
+    def network_file_definitions(
+        self,
+    ) -> typing.Optional[typing.List["NetworkFileDefinition"]]:
+        return typing.cast(typing.Optional[typing.List["NetworkFileDefinition"]], jsii.get(self, "networkFileDefinitions"))
+
+    @network_file_definitions.setter
+    def network_file_definitions(
+        self,
+        value: typing.Optional[typing.List["NetworkFileDefinition"]],
+    ) -> None:
+        jsii.set(self, "networkFileDefinitions", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="signals")
+    def signals(self) -> typing.Optional[typing.List["VehicleSignal"]]:
+        return typing.cast(typing.Optional[typing.List["VehicleSignal"]], jsii.get(self, "signals"))
+
+    @signals.setter
+    def signals(self, value: typing.Optional[typing.List["VehicleSignal"]]) -> None:
+        jsii.set(self, "signals", value)
+
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
 typing.cast(typing.Any, IVehicleModel).__jsii_proxy_class__ = lambda : _IVehicleModelProxy
 
 
+class NetworkFileDefinition(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="cdk-aws-iotfleetwise.NetworkFileDefinition",
+):
+    def __init__(self) -> None:
+        jsii.create(self.__class__, self, [])
+
+    @jsii.member(jsii_name="toObject")
+    def to_object(self) -> typing.Mapping[typing.Any, typing.Any]:
+        return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.invoke(self, "toObject", []))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="definition")
+    def _definition(self) -> typing.Mapping[typing.Any, typing.Any]:
+        return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.get(self, "definition"))
+
+    @_definition.setter
+    def _definition(self, value: typing.Mapping[typing.Any, typing.Any]) -> None:
+        jsii.set(self, "definition", value)
+
+
 class SignalCatalog(
     constructs.Construct,
     metaclass=jsii.JSIIMeta,
@@ -726,6 +901,11 @@ class Vehicle(
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="vehicleId")
+    def vehicle_id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "vehicleId"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vehicleModel")
     def vehicle_model(self) -> "VehicleModel":
@@ -833,6 +1013,25 @@ class VehicleSignal(
         jsii.set(self, "signal", value)
 
 
+class CanDefinition(
+    NetworkFileDefinition,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="cdk-aws-iotfleetwise.CanDefinition",
+):
+    def __init__(
+        self,
+        network_interface: builtins.str,
+        signals_map: typing.Mapping[builtins.str, builtins.str],
+        can_dbc_files: typing.Sequence[builtins.str],
+    ) -> None:
+        '''
+        :param network_interface: -
+        :param signals_map: -
+        :param can_dbc_files: -
+        '''
+        jsii.create(self.__class__, self, [network_interface, signals_map, can_dbc_files])
+
+
 class CanVehicleInterface(
     VehicleInterface,
     metaclass=jsii.JSIIMeta,
@@ -901,13 +1100,17 @@ class SignalCatalogBranch(
 __all__ = [
     "Campaign",
     "CampaignSignal",
+    "CanDefinition",
     "CanVehicleInterface",
     "CanVehicleSignal",
     "CollectionScheme",
+    "Fleet",
     "ICampaign",
+    "IFleet",
     "IServiceCatalogProps",
     "IVehicle",
     "IVehicleModel",
+    "NetworkFileDefinition",
     "SignalCatalog",
     "SignalCatalogBranch",
     "SignalCatalogNode",
